@@ -520,6 +520,13 @@ def compute_total_spectrum(
 
     result = result_fut.compute(scheduler=client)
 
+    if file_obj:
+        file_obj.close()
+
+    # The following code is needed to cause Dask 'distributed>=2021.7.0' to close the h5file.
+    del result_fut
+    _run_dummy_task_on_dask(client=client)
+
     if client_is_local:
         client.close()
 
@@ -609,6 +616,13 @@ def compute_total_spectrum_and_count(
 
     result = result_fut.compute(scheduler=client)
 
+    if file_obj:
+        file_obj.close()
+
+    # The following code is needed to cause Dask 'distributed>=2021.7.0' to close the h5file.
+    del result_fut
+    _run_dummy_task_on_dask(client=client)
+
     if client_is_local:
         client.close()
 
@@ -683,6 +697,17 @@ def _fit_xrf_block(data, data_sel_indices, matv, snip_param, use_snip):
     return data_out
 
 
+def _run_dummy_task_on_dask(*, client):
+    """
+    Runs small task on Dask client. Starting from v2021.7.0, Dask Distributed does not always
+    close HDF5 files, that are open in read-only mode for loading raw data. Submitting and
+    computing a small unrelated tasks seem to prompt the client to release the resources from
+    the previous task and close the files.
+    """
+    rfut = da.sum(da.random.random((1000,), chunks=(10,))).persist(scheduler=client)
+    rfut.compute(scheduler=client)
+
+
 def fit_xrf_map(
     data,
     data_sel_indices,
@@ -824,6 +849,13 @@ def fit_xrf_map(
 
     result = result_fut.compute(scheduler=client)
 
+    if file_obj:
+        file_obj.close()
+
+    # The following code is needed to cause Dask 'distributed>=2021.7.0' to close the h5file.
+    del result_fut
+    _run_dummy_task_on_dask(client=client)
+
     if client_is_local:
         client.close()
 
@@ -1038,6 +1070,13 @@ def compute_selected_rois(
 
     roi_dict_computed = {roi_band_keys[_]: result[:, :, _] for _ in range(len(roi_band_keys))}
 
+    if file_obj:
+        file_obj.close()
+
+    # The following code is needed to cause Dask 'distributed>=2021.7.0' to close the h5file.
+    del result_fut
+    _run_dummy_task_on_dask(client=client)
+
     if client_is_local:
         client.close()
 
