@@ -162,6 +162,21 @@ class ScanMetadataXRF(ScanMetadataBase):
             "sample_name",
             "sample.*",
             "",
+            "param_type",
+            "param_input",
+            "param_shape",
+            "param_snake",
+            "param_dwell",
+            "param_theta",
+            "param_theta_units",
+            "param_delta",
+            "param_delta_units",
+            "param_fast_axis",
+            "param_fast_axis_units",
+            "param_slow_axis",
+            "param_slow_axis_units",
+            "param.*",
+            "",
             "proposal_num",
             "proposal_title",
             "proposal.*",
@@ -212,6 +227,19 @@ class ScanMetadataXRF(ScanMetadataBase):
             "file_software": "software",
             "file_software_version": "version",
             "file_type": "file type",
+            "param_type": "plan type",
+            "param_input": "plan input parameters",
+            "param_shape": "scan shape",
+            "param_snake": "snaking",
+            "param_dwell": "dwell time",
+            "param_theta": "angle theta",
+            "param_theta_units": "angle theta (units)",
+            "param_delta": "delta",
+            "param_delta_units": "delta (units)",
+            "param_fast_axis": "fast axis",
+            "param_fast_axis_units": "fast axis (units)",
+            "param_slow_axis": "slow axis",
+            "param_slow_axis_units": "slow axis (units)",
         }
 
         return descriptions
